from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SignMessageWithPrivateKeyRequest(_message.Message):
    __slots__ = ("private_key", "message")
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    private_key: str
    message: str
    def __init__(self, private_key: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class SignMessageWithPrivateKeyResponse(_message.Message):
    __slots__ = ("signature",)
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    signature: str
    def __init__(self, signature: _Optional[str] = ...) -> None: ...

class VerifyMessageRequest(_message.Message):
    __slots__ = ("message", "signature", "public_key")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    message: str
    signature: str
    public_key: str
    def __init__(self, message: _Optional[str] = ..., signature: _Optional[str] = ..., public_key: _Optional[str] = ...) -> None: ...

class VerifyMessageResponse(_message.Message):
    __slots__ = ("is_valid",)
    IS_VALID_FIELD_NUMBER: _ClassVar[int]
    is_valid: bool
    def __init__(self, is_valid: bool = ...) -> None: ...

class PublicKeyAggregationRequest(_message.Message):
    __slots__ = ("public_keys",)
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    public_keys: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, public_keys: _Optional[_Iterable[str]] = ...) -> None: ...

class PublicKeyAggregationResponse(_message.Message):
    __slots__ = ("public_key", "address")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    public_key: str
    address: str
    def __init__(self, public_key: _Optional[str] = ..., address: _Optional[str] = ...) -> None: ...

class SignatureAggregationRequest(_message.Message):
    __slots__ = ("signatures",)
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, signatures: _Optional[_Iterable[str]] = ...) -> None: ...

class SignatureAggregationResponse(_message.Message):
    __slots__ = ("signature",)
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    signature: str
    def __init__(self, signature: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: wallet.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'wallet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cwallet.proto\x12\x06pactus\"p\n\x0b\x41\x64\x64ressInfo\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x1d\n\npublic_key\x18\x02 \x01(\tR\tpublicKey\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\"\xa5\x01\n\x0bHistoryInfo\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x12\n\x04time\x18\x02 \x01(\rR\x04time\x12!\n\x0cpayload_type\x18\x03 \x01(\tR\x0bpayloadType\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06\x61mount\x18\x05 \x01(\x03R\x06\x61mount\"U\n\x18GetAddressHistoryRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"S\n\x19GetAddressHistoryResponse\x12\x36\n\x0chistory_info\x18\x01 \x03(\x0b\x32\x13.pactus.HistoryInfoR\x0bhistoryInfo\"\xa1\x01\n\x14GetNewAddressRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x36\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\x0e\x32\x13.pactus.AddressTypeR\x0b\x61\x64\x64ressType\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x1a\n\x08password\x18\x04 \x01(\tR\x08password\"p\n\x15GetNewAddressResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x36\n\x0c\x61\x64\x64ress_info\x18\x02 \x01(\x0b\x32\x13.pactus.AddressInfoR\x0b\x61\x64\x64ressInfo\"o\n\x14RestoreWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08mnemonic\x18\x02 \x01(\tR\x08mnemonic\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"8\n\x15RestoreWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"R\n\x13\x43reateWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x04 \x01(\tR\x08password\"2\n\x14\x43reateWalletResponse\x12\x1a\n\x08mnemonic\x18\x02 \x01(\tR\x08mnemonic\"4\n\x11LoadWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"5\n\x12LoadWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"6\n\x13UnloadWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"7\n\x14UnloadWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\";\n\x1aGetValidatorAddressRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\"7\n\x1bGetValidatorAddressResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\x81\x01\n\x19SignRawTransactionRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\'\n\x0fraw_transaction\x18\x02 \x01(\tR\x0erawTransaction\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"y\n\x1aSignRawTransactionResponse\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x34\n\x16signed_raw_transaction\x18\x02 \x01(\tR\x14signedRawTransaction\"9\n\x16GetTotalBalanceRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"_\n\x17GetTotalBalanceResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12#\n\rtotal_balance\x18\x02 \x01(\x03R\x0ctotalBalance\"\x85\x01\n\x12SignMessageRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x18\n\x07\x61\x64\x64ress\x18\x03 \x01(\tR\x07\x61\x64\x64ress\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message\"3\n\x13SignMessageResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\"7\n\x14GetTotalStakeRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"Y\n\x15GetTotalStakeResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1f\n\x0btotal_stake\x18\x02 \x01(\x03R\ntotalStake\"R\n\x15GetAddressInfoRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\x9c\x01\n\x16GetAddressInfoResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x1d\n\npublic_key\x18\x04 \x01(\tR\tpublicKey\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\"\x85\x01\n\x16SetAddressLabelRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x18\n\x07\x61\x64\x64ress\x18\x04 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05label\x18\x05 \x01(\tR\x05label\"\x19\n\x17SetAddressLabelResponse\"\x13\n\x11ListWalletRequest\".\n\x12ListWalletResponse\x12\x18\n\x07wallets\x18\x01 \x03(\tR\x07wallets\"7\n\x14GetWalletInfoRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"\xbd\x01\n\x15GetWalletInfoResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07version\x18\x02 \x01(\x03R\x07version\x12\x18\n\x07network\x18\x03 \x01(\tR\x07network\x12\x1c\n\tencrypted\x18\x04 \x01(\x08R\tencrypted\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x1d\n\ncreated_at\x18\x06 \x01(\x03R\tcreatedAt\"5\n\x12ListAddressRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"_\n\x13ListAddressResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\'\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x13.pactus.AddressInfoR\x04\x64\x61ta*\x84\x01\n\x0b\x41\x64\x64ressType\x12\x19\n\x15\x41\x44\x44RESS_TYPE_TREASURY\x10\x00\x12\x1a\n\x16\x41\x44\x44RESS_TYPE_VALIDATOR\x10\x01\x12\x1c\n\x18\x41\x44\x44RESS_TYPE_BLS_ACCOUNT\x10\x02\x12 \n\x1c\x41\x44\x44RESS_TYPE_ED25519_ACCOUNT\x10\x03\x32\x80\n\n\x06Wallet\x12I\n\x0c\x43reateWallet\x12\x1b.pactus.CreateWalletRequest\x1a\x1c.pactus.CreateWalletResponse\x12L\n\rRestoreWallet\x12\x1c.pactus.RestoreWalletRequest\x1a\x1d.pactus.RestoreWalletResponse\x12\x43\n\nLoadWallet\x12\x19.pactus.LoadWalletRequest\x1a\x1a.pactus.LoadWalletResponse\x12I\n\x0cUnloadWallet\x12\x1b.pactus.UnloadWalletRequest\x1a\x1c.pactus.UnloadWalletResponse\x12R\n\x0fGetTotalBalance\x12\x1e.pactus.GetTotalBalanceRequest\x1a\x1f.pactus.GetTotalBalanceResponse\x12[\n\x12SignRawTransaction\x12!.pactus.SignRawTransactionRequest\x1a\".pactus.SignRawTransactionResponse\x12^\n\x13GetValidatorAddress\x12\".pactus.GetValidatorAddressRequest\x1a#.pactus.GetValidatorAddressResponse\x12L\n\rGetNewAddress\x12\x1c.pactus.GetNewAddressRequest\x1a\x1d.pactus.GetNewAddressResponse\x12X\n\x11GetAddressHistory\x12 .pactus.GetAddressHistoryRequest\x1a!.pactus.GetAddressHistoryResponse\x12\x46\n\x0bSignMessage\x12\x1a.pactus.SignMessageRequest\x1a\x1b.pactus.SignMessageResponse\x12L\n\rGetTotalStake\x12\x1c.pactus.GetTotalStakeRequest\x1a\x1d.pactus.GetTotalStakeResponse\x12O\n\x0eGetAddressInfo\x12\x1d.pactus.GetAddressInfoRequest\x1a\x1e.pactus.GetAddressInfoResponse\x12R\n\x0fSetAddressLabel\x12\x1e.pactus.SetAddressLabelRequest\x1a\x1f.pactus.SetAddressLabelResponse\x12\x43\n\nListWallet\x12\x19.pactus.ListWalletRequest\x1a\x1a.pactus.ListWalletResponse\x12L\n\rGetWalletInfo\x12\x1c.pactus.GetWalletInfoRequest\x1a\x1d.pactus.GetWalletInfoResponse\x12\x46\n\x0bListAddress\x12\x1a.pactus.ListAddressRequest\x1a\x1b.pactus.ListAddressResponseB:\n\x06pactusZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'wallet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\006pactusZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _globals['_ADDRESSTYPE']._serialized_start=3028
  _globals['_ADDRESSTYPE']._serialized_end=3160
  _globals['_ADDRESSINFO']._serialized_start=24
  _globals['_ADDRESSINFO']._serialized_end=136
  _globals['_HISTORYINFO']._serialized_start=139
  _globals['_HISTORYINFO']._serialized_end=304
  _globals['_GETADDRESSHISTORYREQUEST']._serialized_start=306
  _globals['_GETADDRESSHISTORYREQUEST']._serialized_end=391
  _globals['_GETADDRESSHISTORYRESPONSE']._serialized_start=393
  _globals['_GETADDRESSHISTORYRESPONSE']._serialized_end=476
  _globals['_GETNEWADDRESSREQUEST']._serialized_start=479
  _globals['_GETNEWADDRESSREQUEST']._serialized_end=640
  _globals['_GETNEWADDRESSRESPONSE']._serialized_start=642
  _globals['_GETNEWADDRESSRESPONSE']._serialized_end=754
  _globals['_RESTOREWALLETREQUEST']._serialized_start=756
  _globals['_RESTOREWALLETREQUEST']._serialized_end=867
  _globals['_RESTOREWALLETRESPONSE']._serialized_start=869
  _globals['_RESTOREWALLETRESPONSE']._serialized_end=925
  _globals['_CREATEWALLETREQUEST']._serialized_start=927
  _globals['_CREATEWALLETREQUEST']._serialized_end=1009
  _globals['_CREATEWALLETRESPONSE']._serialized_start=1011
  _globals['_CREATEWALLETRESPONSE']._serialized_end=1061
  _globals['_LOADWALLETREQUEST']._serialized_start=1063
  _globals['_LOADWALLETREQUEST']._serialized_end=1115
  _globals['_LOADWALLETRESPONSE']._serialized_start=1117
  _globals['_LOADWALLETRESPONSE']._serialized_end=1170
  _globals['_UNLOADWALLETREQUEST']._serialized_start=1172
  _globals['_UNLOADWALLETREQUEST']._serialized_end=1226
  _globals['_UNLOADWALLETRESPONSE']._serialized_start=1228
  _globals['_UNLOADWALLETRESPONSE']._serialized_end=1283
  _globals['_GETVALIDATORADDRESSREQUEST']._serialized_start=1285
  _globals['_GETVALIDATORADDRESSREQUEST']._serialized_end=1344
  _globals['_GETVALIDATORADDRESSRESPONSE']._serialized_start=1346
  _globals['_GETVALIDATORADDRESSRESPONSE']._serialized_end=1401
  _globals['_SIGNRAWTRANSACTIONREQUEST']._serialized_start=1404
  _globals['_SIGNRAWTRANSACTIONREQUEST']._serialized_end=1533
  _globals['_SIGNRAWTRANSACTIONRESPONSE']._serialized_start=1535
  _globals['_SIGNRAWTRANSACTIONRESPONSE']._serialized_end=1656
  _globals['_GETTOTALBALANCEREQUEST']._serialized_start=1658
  _globals['_GETTOTALBALANCEREQUEST']._serialized_end=1715
  _globals['_GETTOTALBALANCERESPONSE']._serialized_start=1717
  _globals['_GETTOTALBALANCERESPONSE']._serialized_end=1812
  _globals['_SIGNMESSAGEREQUEST']._serialized_start=1815
  _globals['_SIGNMESSAGEREQUEST']._serialized_end=1948
  _globals['_SIGNMESSAGERESPONSE']._serialized_start=1950
  _globals['_SIGNMESSAGERESPONSE']._serialized_end=2001
  _globals['_GETTOTALSTAKEREQUEST']._serialized_start=2003
  _globals['_GETTOTALSTAKEREQUEST']._serialized_end=2058
  _globals['_GETTOTALSTAKERESPONSE']._serialized_start=2060
  _globals['_GETTOTALSTAKERESPONSE']._serialized_end=2149
  _globals['_GETADDRESSINFOREQUEST']._serialized_start=2151
  _globals['_GETADDRESSINFOREQUEST']._serialized_end=2233
  _globals['_GETADDRESSINFORESPONSE']._serialized_start=2236
  _globals['_GETADDRESSINFORESPONSE']._serialized_end=2392
  _globals['_SETADDRESSLABELREQUEST']._serialized_start=2395
  _globals['_SETADDRESSLABELREQUEST']._serialized_end=2528
  _globals['_SETADDRESSLABELRESPONSE']._serialized_start=2530
  _globals['_SETADDRESSLABELRESPONSE']._serialized_end=2555
  _globals['_LISTWALLETREQUEST']._serialized_start=2557
  _globals['_LISTWALLETREQUEST']._serialized_end=2576
  _globals['_LISTWALLETRESPONSE']._serialized_start=2578
  _globals['_LISTWALLETRESPONSE']._serialized_end=2624
  _globals['_GETWALLETINFOREQUEST']._serialized_start=2626
  _globals['_GETWALLETINFOREQUEST']._serialized_end=2681
  _globals['_GETWALLETINFORESPONSE']._serialized_start=2684
  _globals['_GETWALLETINFORESPONSE']._serialized_end=2873
  _globals['_LISTADDRESSREQUEST']._serialized_start=2875
  _globals['_LISTADDRESSREQUEST']._serialized_end=2928
  _globals['_LISTADDRESSRESPONSE']._serialized_start=2930
  _globals['_LISTADDRESSRESPONSE']._serialized_end=3025
  _globals['_WALLET']._serialized_start=3163
  _globals['_WALLET']._serialized_end=4443
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Direction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIRECTION_UNKNOWN: _ClassVar[Direction]
    DIRECTION_INBOUND: _ClassVar[Direction]
    DIRECTION_OUTBOUND: _ClassVar[Direction]
DIRECTION_UNKNOWN: Direction
DIRECTION_INBOUND: Direction
DIRECTION_OUTBOUND: Direction

class GetNetworkInfoRequest(_message.Message):
    __slots__ = ("only_connected",)
    ONLY_CONNECTED_FIELD_NUMBER: _ClassVar[int]
    only_connected: bool
    def __init__(self, only_connected: bool = ...) -> None: ...

class GetNetworkInfoResponse(_message.Message):
    __slots__ = ("network_name", "connected_peers_count", "connected_peers", "metric_info")
    NETWORK_NAME_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_PEERS_COUNT_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_PEERS_FIELD_NUMBER: _ClassVar[int]
    METRIC_INFO_FIELD_NUMBER: _ClassVar[int]
    network_name: str
    connected_peers_count: int
    connected_peers: _containers.RepeatedCompositeFieldContainer[PeerInfo]
    metric_info: MetricInfo
    def __init__(self, network_name: _Optional[str] = ..., connected_peers_count: _Optional[int] = ..., connected_peers: _Optional[_Iterable[_Union[PeerInfo, _Mapping]]] = ..., metric_info: _Optional[_Union[MetricInfo, _Mapping]] = ...) -> None: ...

class GetNodeInfoRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetNodeInfoResponse(_message.Message):
    __slots__ = ("moniker", "agent", "peer_id", "started_at", "reachability", "services", "services_names", "local_addrs", "protocols", "clock_offset", "connection_info", "zmq_publishers", "current_time")
    MONIKER_FIELD_NUMBER: _ClassVar[int]
    AGENT_FIELD_NUMBER: _ClassVar[int]
    PEER_ID_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    REACHABILITY_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    SERVICES_NAMES_FIELD_NUMBER: _ClassVar[int]
    LOCAL_ADDRS_FIELD_NUMBER: _ClassVar[int]
    PROTOCOLS_FIELD_NUMBER: _ClassVar[int]
    CLOCK_OFFSET_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_INFO_FIELD_NUMBER: _ClassVar[int]
    ZMQ_PUBLISHERS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_TIME_FIELD_NUMBER: _ClassVar[int]
    moniker: str
    agent: str
    peer_id: str
    started_at: int
    reachability: str
    services: int
    services_names: str
    local_addrs: _containers.RepeatedScalarFieldContainer[str]
    protocols: _containers.RepeatedScalarFieldContainer[str]
    clock_offset: float
    connection_info: ConnectionInfo
    zmq_publishers: _containers.RepeatedCompositeFieldContainer[ZMQPublisherInfo]
    current_time: int
    def __init__(self, moniker: _Optional[str] = ..., agent: _Optional[str] = ..., peer_id: _Optional[str] = ..., started_at: _Optional[int] = ..., reachability: _Optional[str] = ..., services: _Optional[int] = ..., services_names: _Optional[str] = ..., local_addrs: _Optional[_Iterable[str]] = ..., protocols: _Optional[_Iterable[str]] = ..., clock_offset: _Optional[float] = ..., connection_info: _Optional[_Union[ConnectionInfo, _Mapping]] = ..., zmq_publishers: _Optional[_Iterable[_Union[ZMQPublisherInfo, _Mapping]]] = ..., current_time: _Optional[int] = ...) -> None: ...

class ZMQPublisherInfo(_message.Message):
    __slots__ = ("topic", "address", "hwm")
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    HWM_FIELD_NUMBER: _ClassVar[int]
    topic: str
    address: str
    hwm: int
    def __init__(self, topic: _Optional[str] = ..., address: _Optional[str] = ..., hwm: _Optional[int] = ...) -> None: ...

class PeerInfo(_message.Message):
    __slots__ = ("status", "moniker", "agent", "peer_id", "consensus_keys", "consensus_addresses", "services", "last_block_hash", "height", "last_sent", "last_received", "address", "direction", "protocols", "total_sessions", "completed_sessions", "metric_info", "outbound_hello_sent")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MONIKER_FIELD_NUMBER: _ClassVar[int]
    AGENT_FIELD_NUMBER: _ClassVar[int]
    PEER_ID_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_KEYS_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    SERVICES_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_SENT_FIELD_NUMBER: _ClassVar[int]
    LAST_RECEIVED_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    PROTOCOLS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SESSIONS_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_SESSIONS_FIELD_NUMBER: _ClassVar[int]
    METRIC_INFO_FIELD_NUMBER: _ClassVar[int]
    OUTBOUND_HELLO_SENT_FIELD_NUMBER: _ClassVar[int]
    status: int
    moniker: str
    agent: str
    peer_id: str
    consensus_keys: _containers.RepeatedScalarFieldContainer[str]
    consensus_addresses: _containers.RepeatedScalarFieldContainer[str]
    services: int
    last_block_hash: str
    height: int
    last_sent: int
    last_received: int
    address: str
    direction: Direction
    protocols: _containers.RepeatedScalarFieldContainer[str]
    total_sessions: int
    completed_sessions: int
    metric_info: MetricInfo
    outbound_hello_sent: bool
    def __init__(self, status: _Optional[int] = ..., moniker: _Optional[str] = ..., agent: _Optional[str] = ..., peer_id: _Optional[str] = ..., consensus_keys: _Optional[_Iterable[str]] = ..., consensus_addresses: _Optional[_Iterable[str]] = ..., services: _Optional[int] = ..., last_block_hash: _Optional[str] = ..., height: _Optional[int] = ..., last_sent: _Optional[int] = ..., last_received: _Optional[int] = ..., address: _Optional[str] = ..., direction: _Optional[_Union[Direction, str]] = ..., protocols: _Optional[_Iterable[str]] = ..., total_sessions: _Optional[int] = ..., completed_sessions: _Optional[int] = ..., metric_info: _Optional[_Union[MetricInfo, _Mapping]] = ..., outbound_hello_sent: bool = ...) -> None: ...

class ConnectionInfo(_message.Message):
    __slots__ = ("connections", "inbound_connections", "outbound_connections")
    CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    INBOUND_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    OUTBOUND_CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    connections: int
    inbound_connections: int
    outbound_connections: int
    def __init__(self, connections: _Optional[int] = ..., inbound_connections: _Optional[int] = ..., outbound_connections: _Optional[int] = ...) -> None: ...

class MetricInfo(_message.Message):
    __slots__ = ("total_invalid", "total_sent", "total_received", "message_sent", "message_received")
    class MessageSentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: CounterInfo
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[CounterInfo, _Mapping]] = ...) -> None: ...
    class MessageReceivedEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: CounterInfo
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[CounterInfo, _Mapping]] = ...) -> None: ...
    TOTAL_INVALID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SENT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_RECEIVED_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_SENT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_RECEIVED_FIELD_NUMBER: _ClassVar[int]
    total_invalid: CounterInfo
    total_sent: CounterInfo
    total_received: CounterInfo
    message_sent: _containers.MessageMap[int, CounterInfo]
    message_received: _containers.MessageMap[int, CounterInfo]
    def __init__(self, total_invalid: _Optional[_Union[CounterInfo, _Mapping]] = ..., total_sent: _Optional[_Union[CounterInfo, _Mapping]] = ..., total_received: _Optional[_Union[CounterInfo, _Mapping]] = ..., message_sent: _Optional[_Mapping[int, CounterInfo]] = ..., message_received: _Optional[_Mapping[int, CounterInfo]] = ...) -> None: ...

class CounterInfo(_message.Message):
    __slots__ = ("bytes", "bundles")
    BYTES_FIELD_NUMBER: _ClassVar[int]
    BUNDLES_FIELD_NUMBER: _ClassVar[int]
    bytes: int
    bundles: int
    def __init__(self, bytes: _Optional[int] = ..., bundles: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: blockchain.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'blockchain.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import transaction_pb2 as transaction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x62lockchain.proto\x12\x06pactus\x1a\x11transaction.proto\"-\n\x11GetAccountRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"C\n\x12GetAccountResponse\x12-\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x13.pactus.AccountInfoR\x07\x61\x63\x63ount\"\x1e\n\x1cGetValidatorAddressesRequest\"=\n\x1dGetValidatorAddressesResponse\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\"/\n\x13GetValidatorRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"5\n\x1bGetValidatorByNumberRequest\x12\x16\n\x06number\x18\x01 \x01(\x05R\x06number\"K\n\x14GetValidatorResponse\x12\x33\n\tvalidator\x18\x01 \x01(\x0b\x32\x15.pactus.ValidatorInfoR\tvalidator\"/\n\x13GetPublicKeyRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"5\n\x14GetPublicKeyResponse\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\"_\n\x0fGetBlockRequest\x12\x16\n\x06height\x18\x01 \x01(\rR\x06height\x12\x34\n\tverbosity\x18\x02 \x01(\x0e\x32\x16.pactus.BlockVerbosityR\tverbosity\"\x83\x02\n\x10GetBlockResponse\x12\x16\n\x06height\x18\x01 \x01(\rR\x06height\x12\x12\n\x04hash\x18\x02 \x01(\tR\x04hash\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\tR\x04\x64\x61ta\x12\x1d\n\nblock_time\x18\x04 \x01(\rR\tblockTime\x12/\n\x06header\x18\x05 \x01(\x0b\x32\x17.pactus.BlockHeaderInfoR\x06header\x12\x34\n\tprev_cert\x18\x06 \x01(\x0b\x32\x17.pactus.CertificateInfoR\x08prevCert\x12)\n\x03txs\x18\x07 \x03(\x0b\x32\x17.pactus.TransactionInfoR\x03txs\"-\n\x13GetBlockHashRequest\x12\x16\n\x06height\x18\x01 \x01(\rR\x06height\"*\n\x14GetBlockHashResponse\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"+\n\x15GetBlockHeightRequest\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\"0\n\x16GetBlockHeightResponse\x12\x16\n\x06height\x18\x01 \x01(\rR\x06height\"\x1a\n\x18GetBlockchainInfoRequest\"\x92\x05\n\x19GetBlockchainInfoResponse\x12*\n\x11last_block_height\x18\x01 \x01(\rR\x0flastBlockHeight\x12&\n\x0flast_block_hash\x18\x02 \x01(\tR\rlastBlockHash\x12%\n\x0etotal_accounts\x18\x03 \x01(\x05R\rtotalAccounts\x12)\n\x10total_validators\x18\x04 \x01(\x05R\x0ftotalValidators\x12\x1f\n\x0btotal_power\x18\x05 \x01(\x03R\ntotalPower\x12\'\n\x0f\x63ommittee_power\x18\x06 \x01(\x03R\x0e\x63ommitteePower\x12H\n\x14\x63ommittee_validators\x18\x07 \x03(\x0b\x32\x15.pactus.ValidatorInfoR\x13\x63ommitteeValidators\x12\x1b\n\tis_pruned\x18\x08 \x01(\x08R\x08isPruned\x12%\n\x0epruning_height\x18\t \x01(\rR\rpruningHeight\x12&\n\x0flast_block_time\x18\n \x01(\x03R\rlastBlockTime\x12\x80\x01\n\x1b\x63ommittee_protocol_versions\x18\x0b \x03(\x0b\x32@.pactus.GetBlockchainInfoResponse.CommitteeProtocolVersionsEntryR\x19\x63ommitteeProtocolVersions\x1aL\n\x1e\x43ommitteeProtocolVersionsEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\x19\n\x17GetConsensusInfoRequest\"\x81\x01\n\x18GetConsensusInfoResponse\x12\x30\n\x08proposal\x18\x01 \x01(\x0b\x32\x14.pactus.ProposalInfoR\x08proposal\x12\x33\n\tinstances\x18\x02 \x03(\x0b\x32\x15.pactus.ConsensusInfoR\tinstances\"Q\n\x17GetTxPoolContentRequest\x12\x36\n\x0cpayload_type\x18\x01 \x01(\x0e\x32\x13.pactus.PayloadTypeR\x0bpayloadType\"E\n\x18GetTxPoolContentResponse\x12)\n\x03txs\x18\x01 \x03(\x0b\x32\x17.pactus.TransactionInfoR\x03txs\"\x87\x03\n\rValidatorInfo\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\tR\x04\x64\x61ta\x12\x1d\n\npublic_key\x18\x03 \x01(\tR\tpublicKey\x12\x16\n\x06number\x18\x04 \x01(\x05R\x06number\x12\x14\n\x05stake\x18\x05 \x01(\x03R\x05stake\x12.\n\x13last_bonding_height\x18\x06 \x01(\rR\x11lastBondingHeight\x12\x32\n\x15last_sortition_height\x18\x07 \x01(\rR\x13lastSortitionHeight\x12)\n\x10unbonding_height\x18\x08 \x01(\rR\x0funbondingHeight\x12\x18\n\x07\x61\x64\x64ress\x18\t \x01(\tR\x07\x61\x64\x64ress\x12-\n\x12\x61vailability_score\x18\n \x01(\x01R\x11\x61vailabilityScore\x12)\n\x10protocol_version\x18\x0b \x01(\x05R\x0fprotocolVersion\"\x81\x01\n\x0b\x41\x63\x63ountInfo\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\tR\x04\x64\x61ta\x12\x16\n\x06number\x18\x03 \x01(\x05R\x06number\x12\x18\n\x07\x62\x61lance\x18\x04 \x01(\x03R\x07\x62\x61lance\x12\x18\n\x07\x61\x64\x64ress\x18\x05 \x01(\tR\x07\x61\x64\x64ress\"\xc4\x01\n\x0f\x42lockHeaderInfo\x12\x18\n\x07version\x18\x01 \x01(\x05R\x07version\x12&\n\x0fprev_block_hash\x18\x02 \x01(\tR\rprevBlockHash\x12\x1d\n\nstate_root\x18\x03 \x01(\tR\tstateRoot\x12%\n\x0esortition_seed\x18\x04 \x01(\tR\rsortitionSeed\x12)\n\x10proposer_address\x18\x05 \x01(\tR\x0fproposerAddress\"\x97\x01\n\x0f\x43\x65rtificateInfo\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x1e\n\ncommitters\x18\x03 \x03(\x05R\ncommitters\x12\x1c\n\tabsentees\x18\x04 \x03(\x05R\tabsentees\x12\x1c\n\tsignature\x18\x05 \x01(\tR\tsignature\"\xb1\x01\n\x08VoteInfo\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x10.pactus.VoteTypeR\x04type\x12\x14\n\x05voter\x18\x02 \x01(\tR\x05voter\x12\x1d\n\nblock_hash\x18\x03 \x01(\tR\tblockHash\x12\x14\n\x05round\x18\x04 \x01(\x05R\x05round\x12\x19\n\x08\x63p_round\x18\x05 \x01(\x05R\x07\x63pRound\x12\x19\n\x08\x63p_value\x18\x06 \x01(\x05R\x07\x63pValue\"\x97\x01\n\rConsensusInfo\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06\x61\x63tive\x18\x02 \x01(\x08R\x06\x61\x63tive\x12\x16\n\x06height\x18\x03 \x01(\rR\x06height\x12\x14\n\x05round\x18\x04 \x01(\x05R\x05round\x12&\n\x05votes\x18\x05 \x03(\x0b\x32\x10.pactus.VoteInfoR\x05votes\"y\n\x0cProposalInfo\x12\x16\n\x06height\x18\x01 \x01(\rR\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x1d\n\nblock_data\x18\x03 \x01(\tR\tblockData\x12\x1c\n\tsignature\x18\x04 \x01(\tR\tsignature*f\n\x0e\x42lockVerbosity\x12\x18\n\x14\x42LOCK_VERBOSITY_DATA\x10\x00\x12\x18\n\x14\x42LOCK_VERBOSITY_INFO\x10\x01\x12 \n\x1c\x42LOCK_VERBOSITY_TRANSACTIONS\x10\x02*\xa6\x01\n\x08VoteType\x12\x19\n\x15VOTE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11VOTE_TYPE_PREPARE\x10\x01\x12\x17\n\x13VOTE_TYPE_PRECOMMIT\x10\x02\x12\x19\n\x15VOTE_TYPE_CP_PRE_VOTE\x10\x03\x12\x1a\n\x16VOTE_TYPE_CP_MAIN_VOTE\x10\x04\x12\x18\n\x14VOTE_TYPE_CP_DECIDED\x10\x05\x32\x8b\x07\n\nBlockchain\x12=\n\x08GetBlock\x12\x17.pactus.GetBlockRequest\x1a\x18.pactus.GetBlockResponse\x12I\n\x0cGetBlockHash\x12\x1b.pactus.GetBlockHashRequest\x1a\x1c.pactus.GetBlockHashResponse\x12O\n\x0eGetBlockHeight\x12\x1d.pactus.GetBlockHeightRequest\x1a\x1e.pactus.GetBlockHeightResponse\x12X\n\x11GetBlockchainInfo\x12 .pactus.GetBlockchainInfoRequest\x1a!.pactus.GetBlockchainInfoResponse\x12U\n\x10GetConsensusInfo\x12\x1f.pactus.GetConsensusInfoRequest\x1a .pactus.GetConsensusInfoResponse\x12\x43\n\nGetAccount\x12\x19.pactus.GetAccountRequest\x1a\x1a.pactus.GetAccountResponse\x12I\n\x0cGetValidator\x12\x1b.pactus.GetValidatorRequest\x1a\x1c.pactus.GetValidatorResponse\x12Y\n\x14GetValidatorByNumber\x12#.pactus.GetValidatorByNumberRequest\x1a\x1c.pactus.GetValidatorResponse\x12\x64\n\x15GetValidatorAddresses\x12$.pactus.GetValidatorAddressesRequest\x1a%.pactus.GetValidatorAddressesResponse\x12I\n\x0cGetPublicKey\x12\x1b.pactus.GetPublicKeyRequest\x1a\x1c.pactus.GetPublicKeyResponse\x12U\n\x10GetTxPoolContent\x12\x1f.pactus.GetTxPoolContentRequest\x1a .pactus.GetTxPoolContentResponseB:\n\x06pactusZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blockchain_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\006pactusZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _globals['_GETBLOCKCHAININFORESPONSE_COMMITTEEPROTOCOLVERSIONSENTRY']._loaded_options = None
  _globals['_GETBLOCKCHAININFORESPONSE_COMMITTEEPROTOCOLVERSIONSENTRY']._serialized_options = b'8\001'
  _globals['_BLOCKVERBOSITY']._serialized_start=3426
  _globals['_BLOCKVERBOSITY']._serialized_end=3528
  _globals['_VOTETYPE']._serialized_start=3531
  _globals['_VOTETYPE']._serialized_end=3697
  _globals['_GETACCOUNTREQUEST']._serialized_start=47
  _globals['_GETACCOUNTREQUEST']._serialized_end=92
  _globals['_GETACCOUNTRESPONSE']._serialized_start=94
  _globals['_GETACCOUNTRESPONSE']._serialized_end=161
  _globals['_GETVALIDATORADDRESSESREQUEST']._serialized_start=163
  _globals['_GETVALIDATORADDRESSESREQUEST']._serialized_end=193
  _globals['_GETVALIDATORADDRESSESRESPONSE']._serialized_start=195
  _globals['_GETVALIDATORADDRESSESRESPONSE']._serialized_end=256
  _globals['_GETVALIDATORREQUEST']._serialized_start=258
  _globals['_GETVALIDATORREQUEST']._serialized_end=305
  _globals['_GETVALIDATORBYNUMBERREQUEST']._serialized_start=307
  _globals['_GETVALIDATORBYNUMBERREQUEST']._serialized_end=360
  _globals['_GETVALIDATORRESPONSE']._serialized_start=362
  _globals['_GETVALIDATORRESPONSE']._serialized_end=437
  _globals['_GETPUBLICKEYREQUEST']._serialized_start=439
  _globals['_GETPUBLICKEYREQUEST']._serialized_end=486
  _globals['_GETPUBLICKEYRESPONSE']._serialized_start=488
  _globals['_GETPUBLICKEYRESPONSE']._serialized_end=541
  _globals['_GETBLOCKREQUEST']._serialized_start=543
  _globals['_GETBLOCKREQUEST']._serialized_end=638
  _globals['_GETBLOCKRESPONSE']._serialized_start=641
  _globals['_GETBLOCKRESPONSE']._serialized_end=900
  _globals['_GETBLOCKHASHREQUEST']._serialized_start=902
  _globals['_GETBLOCKHASHREQUEST']._serialized_end=947
  _globals['_GETBLOCKHASHRESPONSE']._serialized_start=949
  _globals['_GETBLOCKHASHRESPONSE']._serialized_end=991
  _globals['_GETBLOCKHEIGHTREQUEST']._serialized_start=993
  _globals['_GETBLOCKHEIGHTREQUEST']._serialized_end=1036
  _globals['_GETBLOCKHEIGHTRESPONSE']._serialized_start=1038
  _globals['_GETBLOCKHEIGHTRESPONSE']._serialized_end=1086
  _globals['_GETBLOCKCHAININFOREQUEST']._serialized_start=1088
  _globals['_GETBLOCKCHAININFOREQUEST']._serialized_end=1114
  _globals['_GETBLOCKCHAININFORESPONSE']._serialized_start=1117
  _globals['_GETBLOCKCHAININFORESPONSE']._serialized_end=1775
  _globals['_GETBLOCKCHAININFORESPONSE_COMMITTEEPROTOCOLVERSIONSENTRY']._serialized_start=1699
  _globals['_GETBLOCKCHAININFORESPONSE_COMMITTEEPROTOCOLVERSIONSENTRY']._serialized_end=1775
  _globals['_GETCONSENSUSINFOREQUEST']._serialized_start=1777
  _globals['_GETCONSENSUSINFOREQUEST']._serialized_end=1802
  _globals['_GETCONSENSUSINFORESPONSE']._serialized_start=1805
  _globals['_GETCONSENSUSINFORESPONSE']._serialized_end=1934
  _globals['_GETTXPOOLCONTENTREQUEST']._serialized_start=1936
  _globals['_GETTXPOOLCONTENTREQUEST']._serialized_end=2017
  _globals['_GETTXPOOLCONTENTRESPONSE']._serialized_start=2019
  _globals['_GETTXPOOLCONTENTRESPONSE']._serialized_end=2088
  _globals['_VALIDATORINFO']._serialized_start=2091
  _globals['_VALIDATORINFO']._serialized_end=2482
  _globals['_ACCOUNTINFO']._serialized_start=2485
  _globals['_ACCOUNTINFO']._serialized_end=2614
  _globals['_BLOCKHEADERINFO']._serialized_start=2617
  _globals['_BLOCKHEADERINFO']._serialized_end=2813
  _globals['_CERTIFICATEINFO']._serialized_start=2816
  _globals['_CERTIFICATEINFO']._serialized_end=2967
  _globals['_VOTEINFO']._serialized_start=2970
  _globals['_VOTEINFO']._serialized_end=3147
  _globals['_CONSENSUSINFO']._serialized_start=3150
  _globals['_CONSENSUSINFO']._serialized_end=3301
  _globals['_PROPOSALINFO']._serialized_start=3303
  _globals['_PROPOSALINFO']._serialized_end=3424
  _globals['_BLOCKCHAIN']._serialized_start=3700
  _globals['_BLOCKCHAIN']._serialized_end=4607
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: utils.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'utils.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0butils.proto\x12\x06pactus\"]\n SignMessageWithPrivateKeyRequest\x12\x1f\n\x0bprivate_key\x18\x01 \x01(\tR\nprivateKey\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"A\n!SignMessageWithPrivateKeyResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\"m\n\x14VerifyMessageRequest\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x1c\n\tsignature\x18\x02 \x01(\tR\tsignature\x12\x1d\n\npublic_key\x18\x03 \x01(\tR\tpublicKey\"2\n\x15VerifyMessageResponse\x12\x19\n\x08is_valid\x18\x01 \x01(\x08R\x07isValid\">\n\x1bPublicKeyAggregationRequest\x12\x1f\n\x0bpublic_keys\x18\x01 \x03(\tR\npublicKeys\"W\n\x1cPublicKeyAggregationResponse\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"=\n\x1bSignatureAggregationRequest\x12\x1e\n\nsignatures\x18\x01 \x03(\tR\nsignatures\"<\n\x1cSignatureAggregationResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature2\x8d\x03\n\x05Utils\x12p\n\x19SignMessageWithPrivateKey\x12(.pactus.SignMessageWithPrivateKeyRequest\x1a).pactus.SignMessageWithPrivateKeyResponse\x12L\n\rVerifyMessage\x12\x1c.pactus.VerifyMessageRequest\x1a\x1d.pactus.VerifyMessageResponse\x12\x61\n\x14PublicKeyAggregation\x12#.pactus.PublicKeyAggregationRequest\x1a$.pactus.PublicKeyAggregationResponse\x12\x61\n\x14SignatureAggregation\x12#.pactus.SignatureAggregationRequest\x1a$.pactus.SignatureAggregationResponseB:\n\x06pactusZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utils_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\006pactusZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _globals['_SIGNMESSAGEWITHPRIVATEKEYREQUEST']._serialized_start=23
  _globals['_SIGNMESSAGEWITHPRIVATEKEYREQUEST']._serialized_end=116
  _globals['_SIGNMESSAGEWITHPRIVATEKEYRESPONSE']._serialized_start=118
  _globals['_SIGNMESSAGEWITHPRIVATEKEYRESPONSE']._serialized_end=183
  _globals['_VERIFYMESSAGEREQUEST']._serialized_start=185
  _globals['_VERIFYMESSAGEREQUEST']._serialized_end=294
  _globals['_VERIFYMESSAGERESPONSE']._serialized_start=296
  _globals['_VERIFYMESSAGERESPONSE']._serialized_end=346
  _globals['_PUBLICKEYAGGREGATIONREQUEST']._serialized_start=348
  _globals['_PUBLICKEYAGGREGATIONREQUEST']._serialized_end=410
  _globals['_PUBLICKEYAGGREGATIONRESPONSE']._serialized_start=412
  _globals['_PUBLICKEYAGGREGATIONRESPONSE']._serialized_end=499
  _globals['_SIGNATUREAGGREGATIONREQUEST']._serialized_start=501
  _globals['_SIGNATUREAGGREGATIONREQUEST']._serialized_end=562
  _globals['_SIGNATUREAGGREGATIONRESPONSE']._serialized_start=564
  _globals['_SIGNATUREAGGREGATIONRESPONSE']._serialized_end=624
  _globals['_UTILS']._serialized_start=627
  _globals['_UTILS']._serialized_end=1024
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import blockchain_pb2 as blockchain__pb2


class BlockchainStub(object):
    """Blockchain service defines RPC methods for interacting with the blockchain.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetBlock = channel.unary_unary(
                '/pactus.Blockchain/GetBlock',
                request_serializer=blockchain__pb2.GetBlockRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetBlockResponse.FromString,
                _registered_method=True)
        self.GetBlockHash = channel.unary_unary(
                '/pactus.Blockchain/GetBlockHash',
                request_serializer=blockchain__pb2.GetBlockHashRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetBlockHashResponse.FromString,
                _registered_method=True)
        self.GetBlockHeight = channel.unary_unary(
                '/pactus.Blockchain/GetBlockHeight',
                request_serializer=blockchain__pb2.GetBlockHeightRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetBlockHeightResponse.FromString,
                _registered_method=True)
        self.GetBlockchainInfo = channel.unary_unary(
                '/pactus.Blockchain/GetBlockchainInfo',
                request_serializer=blockchain__pb2.GetBlockchainInfoRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetBlockchainInfoResponse.FromString,
                _registered_method=True)
        self.GetConsensusInfo = channel.unary_unary(
                '/pactus.Blockchain/GetConsensusInfo',
                request_serializer=blockchain__pb2.GetConsensusInfoRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetConsensusInfoResponse.FromString,
                _registered_method=True)
        self.GetAccount = channel.unary_unary(
                '/pactus.Blockchain/GetAccount',
                request_serializer=blockchain__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetAccountResponse.FromString,
                _registered_method=True)
        self.GetValidator = channel.unary_unary(
                '/pactus.Blockchain/GetValidator',
                request_serializer=blockchain__pb2.GetValidatorRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetValidatorResponse.FromString,
                _registered_method=True)
        self.GetValidatorByNumber = channel.unary_unary(
                '/pactus.Blockchain/GetValidatorByNumber',
                request_serializer=blockchain__pb2.GetValidatorByNumberRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetValidatorResponse.FromString,
                _registered_method=True)
        self.GetValidatorAddresses = channel.unary_unary(
                '/pactus.Blockchain/GetValidatorAddresses',
                request_serializer=blockchain__pb2.GetValidatorAddressesRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetValidatorAddressesResponse.FromString,
                _registered_method=True)
        self.GetPublicKey = channel.unary_unary(
                '/pactus.Blockchain/GetPublicKey',
                request_serializer=blockchain__pb2.GetPublicKeyRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetPublicKeyResponse.FromString,
                _registered_method=True)
        self.GetTxPoolContent = channel.unary_unary(
                '/pactus.Blockchain/GetTxPoolContent',
                request_serializer=blockchain__pb2.GetTxPoolContentRequest.SerializeToString,
                response_deserializer=blockchain__pb2.GetTxPoolContentResponse.FromString,
                _registered_method=True)


class BlockchainServicer(object):
    """Blockchain service defines RPC methods for interacting with the blockchain.
    """

    def GetBlock(self, request, context):
        """GetBlock retrieves information about a block based on the provided request parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockHash(self, request, context):
        """GetBlockHash retrieves the hash of a block at the specified height.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockHeight(self, request, context):
        """GetBlockHeight retrieves the height of a block with the specified hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockchainInfo(self, request, context):
        """GetBlockchainInfo retrieves general information about the blockchain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConsensusInfo(self, request, context):
        """GetConsensusInfo retrieves information about the consensus instances.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """GetAccount retrieves information about an account based on the provided address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidator(self, request, context):
        """GetValidator retrieves information about a validator based on the provided address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidatorByNumber(self, request, context):
        """GetValidatorByNumber retrieves information about a validator based on the provided number.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidatorAddresses(self, request, context):
        """GetValidatorAddresses retrieves a list of all validator addresses.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPublicKey(self, request, context):
        """GetPublicKey retrieves the public key of an account based on the provided address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxPoolContent(self, request, context):
        """GetTxPoolContent retrieves current transactions in the transaction pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BlockchainServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlock,
                    request_deserializer=blockchain__pb2.GetBlockRequest.FromString,
                    response_serializer=blockchain__pb2.GetBlockResponse.SerializeToString,
            ),
            'GetBlockHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockHash,
                    request_deserializer=blockchain__pb2.GetBlockHashRequest.FromString,
                    response_serializer=blockchain__pb2.GetBlockHashResponse.SerializeToString,
            ),
            'GetBlockHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockHeight,
                    request_deserializer=blockchain__pb2.GetBlockHeightRequest.FromString,
                    response_serializer=blockchain__pb2.GetBlockHeightResponse.SerializeToString,
            ),
            'GetBlockchainInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockchainInfo,
                    request_deserializer=blockchain__pb2.GetBlockchainInfoRequest.FromString,
                    response_serializer=blockchain__pb2.GetBlockchainInfoResponse.SerializeToString,
            ),
            'GetConsensusInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConsensusInfo,
                    request_deserializer=blockchain__pb2.GetConsensusInfoRequest.FromString,
                    response_serializer=blockchain__pb2.GetConsensusInfoResponse.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=blockchain__pb2.GetAccountRequest.FromString,
                    response_serializer=blockchain__pb2.GetAccountResponse.SerializeToString,
            ),
            'GetValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidator,
                    request_deserializer=blockchain__pb2.GetValidatorRequest.FromString,
                    response_serializer=blockchain__pb2.GetValidatorResponse.SerializeToString,
            ),
            'GetValidatorByNumber': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidatorByNumber,
                    request_deserializer=blockchain__pb2.GetValidatorByNumberRequest.FromString,
                    response_serializer=blockchain__pb2.GetValidatorResponse.SerializeToString,
            ),
            'GetValidatorAddresses': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidatorAddresses,
                    request_deserializer=blockchain__pb2.GetValidatorAddressesRequest.FromString,
                    response_serializer=blockchain__pb2.GetValidatorAddressesResponse.SerializeToString,
            ),
            'GetPublicKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPublicKey,
                    request_deserializer=blockchain__pb2.GetPublicKeyRequest.FromString,
                    response_serializer=blockchain__pb2.GetPublicKeyResponse.SerializeToString,
            ),
            'GetTxPoolContent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTxPoolContent,
                    request_deserializer=blockchain__pb2.GetTxPoolContentRequest.FromString,
                    response_serializer=blockchain__pb2.GetTxPoolContentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pactus.Blockchain', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('pactus.Blockchain', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Blockchain(object):
    """Blockchain service defines RPC methods for interacting with the blockchain.
    """

    @staticmethod
    def GetBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetBlock',
            blockchain__pb2.GetBlockRequest.SerializeToString,
            blockchain__pb2.GetBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetBlockHash',
            blockchain__pb2.GetBlockHashRequest.SerializeToString,
            blockchain__pb2.GetBlockHashResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetBlockHeight',
            blockchain__pb2.GetBlockHeightRequest.SerializeToString,
            blockchain__pb2.GetBlockHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockchainInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetBlockchainInfo',
            blockchain__pb2.GetBlockchainInfoRequest.SerializeToString,
            blockchain__pb2.GetBlockchainInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConsensusInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetConsensusInfo',
            blockchain__pb2.GetConsensusInfoRequest.SerializeToString,
            blockchain__pb2.GetConsensusInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetAccount',
            blockchain__pb2.GetAccountRequest.SerializeToString,
            blockchain__pb2.GetAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetValidator',
            blockchain__pb2.GetValidatorRequest.SerializeToString,
            blockchain__pb2.GetValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetValidatorByNumber(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetValidatorByNumber',
            blockchain__pb2.GetValidatorByNumberRequest.SerializeToString,
            blockchain__pb2.GetValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetValidatorAddresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetValidatorAddresses',
            blockchain__pb2.GetValidatorAddressesRequest.SerializeToString,
            blockchain__pb2.GetValidatorAddressesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPublicKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetPublicKey',
            blockchain__pb2.GetPublicKeyRequest.SerializeToString,
            blockchain__pb2.GetPublicKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTxPoolContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pactus.Blockchain/GetTxPoolContent',
            blockchain__pb2.GetTxPoolContentRequest.SerializeToString,
            blockchain__pb2.GetTxPoolContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PayloadType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PAYLOAD_TYPE_UNSPECIFIED: _ClassVar[PayloadType]
    PAYLOAD_TYPE_TRANSFER: _ClassVar[PayloadType]
    PAYLOAD_TYPE_BOND: _ClassVar[PayloadType]
    PAYLOAD_TYPE_SORTITION: _ClassVar[PayloadType]
    PAYLOAD_TYPE_UNBOND: _ClassVar[PayloadType]
    PAYLOAD_TYPE_WITHDRAW: _ClassVar[PayloadType]
    PAYLOAD_TYPE_BATCH_TRANSFER: _ClassVar[PayloadType]

class TransactionVerbosity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TRANSACTION_VERBOSITY_DATA: _ClassVar[TransactionVerbosity]
    TRANSACTION_VERBOSITY_INFO: _ClassVar[TransactionVerbosity]
PAYLOAD_TYPE_UNSPECIFIED: PayloadType
PAYLOAD_TYPE_TRANSFER: PayloadType
PAYLOAD_TYPE_BOND: PayloadType
PAYLOAD_TYPE_SORTITION: PayloadType
PAYLOAD_TYPE_UNBOND: PayloadType
PAYLOAD_TYPE_WITHDRAW: PayloadType
PAYLOAD_TYPE_BATCH_TRANSFER: PayloadType
TRANSACTION_VERBOSITY_DATA: TransactionVerbosity
TRANSACTION_VERBOSITY_INFO: TransactionVerbosity

class GetTransactionRequest(_message.Message):
    __slots__ = ("id", "verbosity")
    ID_FIELD_NUMBER: _ClassVar[int]
    VERBOSITY_FIELD_NUMBER: _ClassVar[int]
    id: str
    verbosity: TransactionVerbosity
    def __init__(self, id: _Optional[str] = ..., verbosity: _Optional[_Union[TransactionVerbosity, str]] = ...) -> None: ...

class GetTransactionResponse(_message.Message):
    __slots__ = ("block_height", "block_time", "transaction")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    block_time: int
    transaction: TransactionInfo
    def __init__(self, block_height: _Optional[int] = ..., block_time: _Optional[int] = ..., transaction: _Optional[_Union[TransactionInfo, _Mapping]] = ...) -> None: ...

class CalculateFeeRequest(_message.Message):
    __slots__ = ("amount", "payload_type", "fixed_amount")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_TYPE_FIELD_NUMBER: _ClassVar[int]
    FIXED_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: int
    payload_type: PayloadType
    fixed_amount: bool
    def __init__(self, amount: _Optional[int] = ..., payload_type: _Optional[_Union[PayloadType, str]] = ..., fixed_amount: bool = ...) -> None: ...

class CalculateFeeResponse(_message.Message):
    __slots__ = ("amount", "fee")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    amount: int
    fee: int
    def __init__(self, amount: _Optional[int] = ..., fee: _Optional[int] = ...) -> None: ...

class BroadcastTransactionRequest(_message.Message):
    __slots__ = ("signed_raw_transaction",)
    SIGNED_RAW_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    signed_raw_transaction: str
    def __init__(self, signed_raw_transaction: _Optional[str] = ...) -> None: ...

class BroadcastTransactionResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetRawTransferTransactionRequest(_message.Message):
    __slots__ = ("lock_time", "sender", "receiver", "amount", "fee", "memo")
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    lock_time: int
    sender: str
    receiver: str
    amount: int
    fee: int
    memo: str
    def __init__(self, lock_time: _Optional[int] = ..., sender: _Optional[str] = ..., receiver: _Optional[str] = ..., amount: _Optional[int] = ..., fee: _Optional[int] = ..., memo: _Optional[str] = ...) -> None: ...

class GetRawBondTransactionRequest(_message.Message):
    __slots__ = ("lock_time", "sender", "receiver", "stake", "public_key", "fee", "memo")
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    lock_time: int
    sender: str
    receiver: str
    stake: int
    public_key: str
    fee: int
    memo: str
    def __init__(self, lock_time: _Optional[int] = ..., sender: _Optional[str] = ..., receiver: _Optional[str] = ..., stake: _Optional[int] = ..., public_key: _Optional[str] = ..., fee: _Optional[int] = ..., memo: _Optional[str] = ...) -> None: ...

class GetRawUnbondTransactionRequest(_message.Message):
    __slots__ = ("lock_time", "validator_address", "memo")
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    lock_time: int
    validator_address: str
    memo: str
    def __init__(self, lock_time: _Optional[int] = ..., validator_address: _Optional[str] = ..., memo: _Optional[str] = ...) -> None: ...

class GetRawWithdrawTransactionRequest(_message.Message):
    __slots__ = ("lock_time", "validator_address", "account_address", "amount", "fee", "memo")
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    lock_time: int
    validator_address: str
    account_address: str
    amount: int
    fee: int
    memo: str
    def __init__(self, lock_time: _Optional[int] = ..., validator_address: _Optional[str] = ..., account_address: _Optional[str] = ..., amount: _Optional[int] = ..., fee: _Optional[int] = ..., memo: _Optional[str] = ...) -> None: ...

class GetRawBatchTransferTransactionRequest(_message.Message):
    __slots__ = ("lock_time", "sender", "recipients", "fee", "memo")
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    lock_time: int
    sender: str
    recipients: _containers.RepeatedCompositeFieldContainer[Recipient]
    fee: int
    memo: str
    def __init__(self, lock_time: _Optional[int] = ..., sender: _Optional[str] = ..., recipients: _Optional[_Iterable[_Union[Recipient, _Mapping]]] = ..., fee: _Optional[int] = ..., memo: _Optional[str] = ...) -> None: ...

class GetRawTransactionResponse(_message.Message):
    __slots__ = ("raw_transaction", "id")
    RAW_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    raw_transaction: str
    id: str
    def __init__(self, raw_transaction: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class PayloadTransfer(_message.Message):
    __slots__ = ("sender", "receiver", "amount")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    sender: str
    receiver: str
    amount: int
    def __init__(self, sender: _Optional[str] = ..., receiver: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...

class PayloadBond(_message.Message):
    __slots__ = ("sender", "receiver", "stake", "public_key")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    sender: str
    receiver: str
    stake: int
    public_key: str
    def __init__(self, sender: _Optional[str] = ..., receiver: _Optional[str] = ..., stake: _Optional[int] = ..., public_key: _Optional[str] = ...) -> None: ...

class PayloadSortition(_message.Message):
    __slots__ = ("address", "proof")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROOF_FIELD_NUMBER: _ClassVar[int]
    address: str
    proof: str
    def __init__(self, address: _Optional[str] = ..., proof: _Optional[str] = ...) -> None: ...

class PayloadUnbond(_message.Message):
    __slots__ = ("validator",)
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    validator: str
    def __init__(self, validator: _Optional[str] = ...) -> None: ...

class PayloadWithdraw(_message.Message):
    __slots__ = ("validator_address", "account_address", "amount")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    account_address: str
    amount: int
    def __init__(self, validator_address: _Optional[str] = ..., account_address: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...

class PayloadBatchTransfer(_message.Message):
    __slots__ = ("sender", "recipients")
    SENDER_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    sender: str
    recipients: _containers.RepeatedCompositeFieldContainer[Recipient]
    def __init__(self, sender: _Optional[str] = ..., recipients: _Optional[_Iterable[_Union[Recipient, _Mapping]]] = ...) -> None: ...

class Recipient(_message.Message):
    __slots__ = ("receiver", "amount")
    RECEIVER_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    receiver: str
    amount: int
    def __init__(self, receiver: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...

class TransactionInfo(_message.Message):
    __slots__ = ("id", "data", "version", "lock_time", "value", "fee", "payload_type", "transfer", "bond", "sortition", "unbond", "withdraw", "batch_transfer", "memo", "public_key", "signature")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    LOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_TYPE_FIELD_NUMBER: _ClassVar[int]
    TRANSFER_FIELD_NUMBER: _ClassVar[int]
    BOND_FIELD_NUMBER: _ClassVar[int]
    SORTITION_FIELD_NUMBER: _ClassVar[int]
    UNBOND_FIELD_NUMBER: _ClassVar[int]
    WITHDRAW_FIELD_NUMBER: _ClassVar[int]
    BATCH_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    id: str
    data: str
    version: int
    lock_time: int
    value: int
    fee: int
    payload_type: PayloadType
    transfer: PayloadTransfer
    bond: PayloadBond
    sortition: PayloadSortition
    unbond: PayloadUnbond
    withdraw: PayloadWithdraw
    batch_transfer: PayloadBatchTransfer
    memo: str
    public_key: str
    signature: str
    def __init__(self, id: _Optional[str] = ..., data: _Optional[str] = ..., version: _Optional[int] = ..., lock_time: _Optional[int] = ..., value: _Optional[int] = ..., fee: _Optional[int] = ..., payload_type: _Optional[_Union[PayloadType, str]] = ..., transfer: _Optional[_Union[PayloadTransfer, _Mapping]] = ..., bond: _Optional[_Union[PayloadBond, _Mapping]] = ..., sortition: _Optional[_Union[PayloadSortition, _Mapping]] = ..., unbond: _Optional[_Union[PayloadUnbond, _Mapping]] = ..., withdraw: _Optional[_Union[PayloadWithdraw, _Mapping]] = ..., batch_transfer: _Optional[_Union[PayloadBatchTransfer, _Mapping]] = ..., memo: _Optional[str] = ..., public_key: _Optional[str] = ..., signature: _Optional[str] = ...) -> None: ...

class DecodeRawTransactionRequest(_message.Message):
    __slots__ = ("raw_transaction",)
    RAW_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    raw_transaction: str
    def __init__(self, raw_transaction: _Optional[str] = ...) -> None: ...

class DecodeRawTransactionResponse(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: TransactionInfo
    def __init__(self, transaction: _Optional[_Union[TransactionInfo, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: transaction.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11transaction.proto\x12\x06pactus\"c\n\x15GetTransactionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12:\n\tverbosity\x18\x02 \x01(\x0e\x32\x1c.pactus.TransactionVerbosityR\tverbosity\"\x95\x01\n\x16GetTransactionResponse\x12!\n\x0c\x62lock_height\x18\x01 \x01(\rR\x0b\x62lockHeight\x12\x1d\n\nblock_time\x18\x02 \x01(\rR\tblockTime\x12\x39\n\x0btransaction\x18\x03 \x01(\x0b\x32\x17.pactus.TransactionInfoR\x0btransaction\"\x88\x01\n\x13\x43\x61lculateFeeRequest\x12\x16\n\x06\x61mount\x18\x01 \x01(\x03R\x06\x61mount\x12\x36\n\x0cpayload_type\x18\x02 \x01(\x0e\x32\x13.pactus.PayloadTypeR\x0bpayloadType\x12!\n\x0c\x66ixed_amount\x18\x03 \x01(\x08R\x0b\x66ixedAmount\"@\n\x14\x43\x61lculateFeeResponse\x12\x16\n\x06\x61mount\x18\x01 \x01(\x03R\x06\x61mount\x12\x10\n\x03\x66\x65\x65\x18\x02 \x01(\x03R\x03\x66\x65\x65\"S\n\x1b\x42roadcastTransactionRequest\x12\x34\n\x16signed_raw_transaction\x18\x01 \x01(\tR\x14signedRawTransaction\".\n\x1c\x42roadcastTransactionResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb1\x01\n GetRawTransferTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x03 \x01(\tR\x08receiver\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\x12\x10\n\x03\x66\x65\x65\x18\x05 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x06 \x01(\tR\x04memo\"\xca\x01\n\x1cGetRawBondTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x03 \x01(\tR\x08receiver\x12\x14\n\x05stake\x18\x04 \x01(\x03R\x05stake\x12\x1d\n\npublic_key\x18\x05 \x01(\tR\tpublicKey\x12\x10\n\x03\x66\x65\x65\x18\x06 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x07 \x01(\tR\x04memo\"~\n\x1eGetRawUnbondTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12+\n\x11validator_address\x18\x03 \x01(\tR\x10validatorAddress\x12\x12\n\x04memo\x18\x04 \x01(\tR\x04memo\"\xd3\x01\n GetRawWithdrawTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\x12\'\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\x12\x10\n\x03\x66\x65\x65\x18\x05 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x06 \x01(\tR\x04memo\"\xb5\x01\n%GetRawBatchTransferTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x31\n\nrecipients\x18\x03 \x03(\x0b\x32\x11.pactus.RecipientR\nrecipients\x12\x10\n\x03\x66\x65\x65\x18\x04 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x05 \x01(\tR\x04memo\"T\n\x19GetRawTransactionResponse\x12\'\n\x0fraw_transaction\x18\x01 \x01(\tR\x0erawTransaction\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\"]\n\x0fPayloadTransfer\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x02 \x01(\tR\x08receiver\x12\x16\n\x06\x61mount\x18\x03 \x01(\x03R\x06\x61mount\"v\n\x0bPayloadBond\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x02 \x01(\tR\x08receiver\x12\x14\n\x05stake\x18\x03 \x01(\x03R\x05stake\x12\x1d\n\npublic_key\x18\x04 \x01(\tR\tpublicKey\"B\n\x10PayloadSortition\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05proof\x18\x02 \x01(\tR\x05proof\"-\n\rPayloadUnbond\x12\x1c\n\tvalidator\x18\x01 \x01(\tR\tvalidator\"\x7f\n\x0fPayloadWithdraw\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x16\n\x06\x61mount\x18\x03 \x01(\x03R\x06\x61mount\"a\n\x14PayloadBatchTransfer\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x31\n\nrecipients\x18\x02 \x03(\x0b\x32\x11.pactus.RecipientR\nrecipients\"?\n\tRecipient\x12\x1a\n\x08receiver\x18\x01 \x01(\tR\x08receiver\x12\x16\n\x06\x61mount\x18\x02 \x01(\x03R\x06\x61mount\"\xf3\x04\n\x0fTransactionInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\tR\x04\x64\x61ta\x12\x18\n\x07version\x18\x03 \x01(\x05R\x07version\x12\x1b\n\tlock_time\x18\x04 \x01(\rR\x08lockTime\x12\x14\n\x05value\x18\x05 \x01(\x03R\x05value\x12\x10\n\x03\x66\x65\x65\x18\x06 \x01(\x03R\x03\x66\x65\x65\x12\x36\n\x0cpayload_type\x18\x07 \x01(\x0e\x32\x13.pactus.PayloadTypeR\x0bpayloadType\x12\x35\n\x08transfer\x18\x1e \x01(\x0b\x32\x17.pactus.PayloadTransferH\x00R\x08transfer\x12)\n\x04\x62ond\x18\x1f \x01(\x0b\x32\x13.pactus.PayloadBondH\x00R\x04\x62ond\x12\x38\n\tsortition\x18  \x01(\x0b\x32\x18.pactus.PayloadSortitionH\x00R\tsortition\x12/\n\x06unbond\x18! \x01(\x0b\x32\x15.pactus.PayloadUnbondH\x00R\x06unbond\x12\x35\n\x08withdraw\x18\" \x01(\x0b\x32\x17.pactus.PayloadWithdrawH\x00R\x08withdraw\x12\x45\n\x0e\x62\x61tch_transfer\x18# \x01(\x0b\x32\x1c.pactus.PayloadBatchTransferH\x00R\rbatchTransfer\x12\x12\n\x04memo\x18\x08 \x01(\tR\x04memo\x12\x1d\n\npublic_key\x18\t \x01(\tR\tpublicKey\x12\x1c\n\tsignature\x18\n \x01(\tR\tsignatureB\t\n\x07payload\"F\n\x1b\x44\x65\x63odeRawTransactionRequest\x12\'\n\x0fraw_transaction\x18\x01 \x01(\tR\x0erawTransaction\"Y\n\x1c\x44\x65\x63odeRawTransactionResponse\x12\x39\n\x0btransaction\x18\x01 \x01(\x0b\x32\x17.pactus.TransactionInfoR\x0btransaction*\xce\x01\n\x0bPayloadType\x12\x1c\n\x18PAYLOAD_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15PAYLOAD_TYPE_TRANSFER\x10\x01\x12\x15\n\x11PAYLOAD_TYPE_BOND\x10\x02\x12\x1a\n\x16PAYLOAD_TYPE_SORTITION\x10\x03\x12\x17\n\x13PAYLOAD_TYPE_UNBOND\x10\x04\x12\x19\n\x15PAYLOAD_TYPE_WITHDRAW\x10\x05\x12\x1f\n\x1bPAYLOAD_TYPE_BATCH_TRANSFER\x10\x06*V\n\x14TransactionVerbosity\x12\x1e\n\x1aTRANSACTION_VERBOSITY_DATA\x10\x00\x12\x1e\n\x1aTRANSACTION_VERBOSITY_INFO\x10\x01\x32\xff\x06\n\x0bTransaction\x12O\n\x0eGetTransaction\x12\x1d.pactus.GetTransactionRequest\x1a\x1e.pactus.GetTransactionResponse\x12I\n\x0c\x43\x61lculateFee\x12\x1b.pactus.CalculateFeeRequest\x1a\x1c.pactus.CalculateFeeResponse\x12\x61\n\x14\x42roadcastTransaction\x12#.pactus.BroadcastTransactionRequest\x1a$.pactus.BroadcastTransactionResponse\x12h\n\x19GetRawTransferTransaction\x12(.pactus.GetRawTransferTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12`\n\x15GetRawBondTransaction\x12$.pactus.GetRawBondTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12\x64\n\x17GetRawUnbondTransaction\x12&.pactus.GetRawUnbondTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12h\n\x19GetRawWithdrawTransaction\x12(.pactus.GetRawWithdrawTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12r\n\x1eGetRawBatchTransferTransaction\x12-.pactus.GetRawBatchTransferTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12\x61\n\x14\x44\x65\x63odeRawTransaction\x12#.pactus.DecodeRawTransactionRequest\x1a$.pactus.DecodeRawTransactionResponseB:\n\x06pactusZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\006pactusZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _globals['_PAYLOADTYPE']._serialized_start=3034
  _globals['_PAYLOADTYPE']._serialized_end=3240
  _globals['_TRANSACTIONVERBOSITY']._serialized_start=3242
  _globals['_TRANSACTIONVERBOSITY']._serialized_end=3328
  _globals['_GETTRANSACTIONREQUEST']._serialized_start=29
  _globals['_GETTRANSACTIONREQUEST']._serialized_end=128
  _globals['_GETTRANSACTIONRESPONSE']._serialized_start=131
  _globals['_GETTRANSACTIONRESPONSE']._serialized_end=280
  _globals['_CALCULATEFEEREQUEST']._serialized_start=283
  _globals['_CALCULATEFEEREQUEST']._serialized_end=419
  _globals['_CALCULATEFEERESPONSE']._serialized_start=421
  _globals['_CALCULATEFEERESPONSE']._serialized_end=485
  _globals['_BROADCASTTRANSACTIONREQUEST']._serialized_start=487
  _globals['_BROADCASTTRANSACTIONREQUEST']._serialized_end=570
  _globals['_BROADCASTTRANSACTIONRESPONSE']._serialized_start=572
  _globals['_BROADCASTTRANSACTIONRESPONSE']._serialized_end=618
  _globals['_GETRAWTRANSFERTRANSACTIONREQUEST']._serialized_start=621
  _globals['_GETRAWTRANSFERTRANSACTIONREQUEST']._serialized_end=798
  _globals['_GETRAWBONDTRANSACTIONREQUEST']._serialized_start=801
  _globals['_GETRAWBONDTRANSACTIONREQUEST']._serialized_end=1003
  _globals['_GETRAWUNBONDTRANSACTIONREQUEST']._serialized_start=1005
  _globals['_GETRAWUNBONDTRANSACTIONREQUEST']._serialized_end=1131
  _globals['_GETRAWWITHDRAWTRANSACTIONREQUEST']._serialized_start=1134
  _globals['_GETRAWWITHDRAWTRANSACTIONREQUEST']._serialized_end=1345
  _globals['_GETRAWBATCHTRANSFERTRANSACTIONREQUEST']._serialized_start=1348
  _globals['_GETRAWBATCHTRANSFERTRANSACTIONREQUEST']._serialized_end=1529
  _globals['_GETRAWTRANSACTIONRESPONSE']._serialized_start=1531
  _globals['_GETRAWTRANSACTIONRESPONSE']._serialized_end=1615
  _globals['_PAYLOADTRANSFER']._serialized_start=1617
  _globals['_PAYLOADTRANSFER']._serialized_end=1710
  _globals['_PAYLOADBOND']._serialized_start=1712
  _globals['_PAYLOADBOND']._serialized_end=1830
  _globals['_PAYLOADSORTITION']._serialized_start=1832
  _globals['_PAYLOADSORTITION']._serialized_end=1898
  _globals['_PAYLOADUNBOND']._serialized_start=1900
  _globals['_PAYLOADUNBOND']._serialized_end=1945
  _globals['_PAYLOADWITHDRAW']._serialized_start=1947
  _globals['_PAYLOADWITHDRAW']._serialized_end=2074
  _globals['_PAYLOADBATCHTRANSFER']._serialized_start=2076
  _globals['_PAYLOADBATCHTRANSFER']._serialized_end=2173
  _globals['_RECIPIENT']._serialized_start=2175
  _globals['_RECIPIENT']._serialized_end=2238
  _globals['_TRANSACTIONINFO']._serialized_start=2241
  _globals['_TRANSACTIONINFO']._serialized_end=2868
  _globals['_DECODERAWTRANSACTIONREQUEST']._serialized_start=2870
  _globals['_DECODERAWTRANSACTIONREQUEST']._serialized_end=2940
  _globals['_DECODERAWTRANSACTIONRESPONSE']._serialized_start=2942
  _globals['_DECODERAWTRANSACTIONRESPONSE']._serialized_end=3031
  _globals['_TRANSACTION']._serialized_start=3331
  _globals['_TRANSACTION']._serialized_end=4226
# @@protoc_insertion_point(module_scope)
